import { PageRequest } from "../../base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QueryBalanceRequest, QueryBalanceResponse, QueryAllBalancesRequest, QueryAllBalancesResponse, QuerySpendableBalancesRequest, QuerySpendableBalancesResponse, QueryTotalSupplyRequest, QueryTotalSupplyResponse, QuerySupplyOfRequest, QuerySupplyOfResponse, QueryParamsRequest, QueryParamsResponse, QueryDenomMetadataRequest, QueryDenomMetadataResponse, QueryDenomsMetadataRequest, QueryDenomsMetadataResponse, QueryDenomOwnersRequest, QueryDenomOwnersResponse } from "./query";
import { createQueryRpc } from "@interchainjs/utils";
export class QueryClientImpl {
    rpc;
    constructor(endpoint) {
        if (typeof endpoint === "string") {
            this.rpc = createQueryRpc(endpoint);
        }
        else {
            this.rpc = endpoint;
        }
    }
    /* Balance queries the balance of a single coin for a single account. */
    balance = async (request) => {
        const data = QueryBalanceRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "Balance", data);
        return promise.then(data => QueryBalanceResponse.decode(new BinaryReader(data)));
    };
    /* AllBalances queries the balance of all coins for a single account. */
    allBalances = async (request) => {
        const data = QueryAllBalancesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "AllBalances", data);
        return promise.then(data => QueryAllBalancesResponse.decode(new BinaryReader(data)));
    };
    /* SpendableBalances queries the spenable balance of all coins for a single
     account. */
    spendableBalances = async (request) => {
        const data = QuerySpendableBalancesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "SpendableBalances", data);
        return promise.then(data => QuerySpendableBalancesResponse.decode(new BinaryReader(data)));
    };
    /* TotalSupply queries the total supply of all coins. */
    totalSupply = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryTotalSupplyRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "TotalSupply", data);
        return promise.then(data => QueryTotalSupplyResponse.decode(new BinaryReader(data)));
    };
    /* SupplyOf queries the supply of a single coin. */
    supplyOf = async (request) => {
        const data = QuerySupplyOfRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "SupplyOf", data);
        return promise.then(data => QuerySupplyOfResponse.decode(new BinaryReader(data)));
    };
    /* Params queries the parameters of x/bank module. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
    /* DenomsMetadata queries the client metadata of a given coin denomination. */
    denomMetadata = async (request) => {
        const data = QueryDenomMetadataRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "DenomMetadata", data);
        return promise.then(data => QueryDenomMetadataResponse.decode(new BinaryReader(data)));
    };
    /* DenomsMetadata queries the client metadata for all registered coin
     denominations. */
    denomsMetadata = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryDenomsMetadataRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "DenomsMetadata", data);
        return promise.then(data => QueryDenomsMetadataResponse.decode(new BinaryReader(data)));
    };
    /* DenomOwners queries for all account addresses that own a particular token
     denomination. */
    denomOwners = async (request) => {
        const data = QueryDenomOwnersRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.bank.v1beta1.Query", "DenomOwners", data);
        return promise.then(data => QueryDenomOwnersResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const useBalance = ({ request, options }) => {
        return useQuery(["balanceQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.balance(request);
        }, options);
    };
    const useAllBalances = ({ request, options }) => {
        return useQuery(["allBalancesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.allBalances(request);
        }, options);
    };
    const useSpendableBalances = ({ request, options }) => {
        return useQuery(["spendableBalancesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.spendableBalances(request);
        }, options);
    };
    const useTotalSupply = ({ request, options }) => {
        return useQuery(["totalSupplyQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.totalSupply(request);
        }, options);
    };
    const useSupplyOf = ({ request, options }) => {
        return useQuery(["supplyOfQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.supplyOf(request);
        }, options);
    };
    const useParams = ({ request, options }) => {
        return useQuery(["paramsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.params(request);
        }, options);
    };
    const useDenomMetadata = ({ request, options }) => {
        return useQuery(["denomMetadataQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.denomMetadata(request);
        }, options);
    };
    const useDenomsMetadata = ({ request, options }) => {
        return useQuery(["denomsMetadataQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.denomsMetadata(request);
        }, options);
    };
    const useDenomOwners = ({ request, options }) => {
        return useQuery(["denomOwnersQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.denomOwners(request);
        }, options);
    };
    return {
        /** Balance queries the balance of a single coin for a single account. */ useBalance,
        /** AllBalances queries the balance of all coins for a single account. */ useAllBalances,
        /**
         * SpendableBalances queries the spenable balance of all coins for a single
         * account.
         */
        useSpendableBalances,
        /** TotalSupply queries the total supply of all coins. */ useTotalSupply,
        /** SupplyOf queries the supply of a single coin. */ useSupplyOf,
        /** Params queries the parameters of x/bank module. */ useParams,
        /** DenomsMetadata queries the client metadata of a given coin denomination. */ useDenomMetadata,
        /**
         * DenomsMetadata queries the client metadata for all registered coin
         * denominations.
         */
        useDenomsMetadata,
        /**
         * DenomOwners queries for all account addresses that own a particular token
         * denomination.
         */
        useDenomOwners
    };
};
