import { PageRequest } from "../../base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QueryBalanceRequest, QueryBalanceResponse, QueryOwnerRequest, QueryOwnerResponse, QuerySupplyRequest, QuerySupplyResponse, QueryNFTsRequest, QueryNFTsResponse, QueryNFTRequest, QueryNFTResponse, QueryClassRequest, QueryClassResponse, QueryClassesRequest, QueryClassesResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721 */
    balance = async (request) => {
        const data = QueryBalanceRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "Balance", data);
        return promise.then(data => QueryBalanceResponse.decode(new BinaryReader(data)));
    };
    /* Owner queries the owner of the NFT based on its class and id, same as ownerOf in ERC721 */
    owner = async (request) => {
        const data = QueryOwnerRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "Owner", data);
        return promise.then(data => QueryOwnerResponse.decode(new BinaryReader(data)));
    };
    /* Supply queries the number of NFTs from the given class, same as totalSupply of ERC721. */
    supply = async (request) => {
        const data = QuerySupplyRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "Supply", data);
        return promise.then(data => QuerySupplyResponse.decode(new BinaryReader(data)));
    };
    /* NFTs queries all NFTs of a given class or owner,choose at least one of the two, similar to tokenByIndex in
     ERC721Enumerable */
    nFTs = async (request) => {
        const data = QueryNFTsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "NFTs", data);
        return promise.then(data => QueryNFTsResponse.decode(new BinaryReader(data)));
    };
    /* NFT queries an NFT based on its class and id. */
    nFT = async (request) => {
        const data = QueryNFTRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "NFT", data);
        return promise.then(data => QueryNFTResponse.decode(new BinaryReader(data)));
    };
    /* Class queries an NFT class based on its id */
    class = async (request) => {
        const data = QueryClassRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "Class", data);
        return promise.then(data => QueryClassResponse.decode(new BinaryReader(data)));
    };
    /* Classes queries all NFT classes */
    classes = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryClassesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.nft.v1beta1.Query", "Classes", data);
        return promise.then(data => QueryClassesResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const useBalance = ({ request, options }) => {
        return useQuery(["balanceQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.balance(request);
        }, options);
    };
    const useOwner = ({ request, options }) => {
        return useQuery(["ownerQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.owner(request);
        }, options);
    };
    const useSupply = ({ request, options }) => {
        return useQuery(["supplyQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.supply(request);
        }, options);
    };
    const useNFTs = ({ request, options }) => {
        return useQuery(["nFTsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.nFTs(request);
        }, options);
    };
    const useNFT = ({ request, options }) => {
        return useQuery(["nFTQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.nFT(request);
        }, options);
    };
    const useClass = ({ request, options }) => {
        return useQuery(["classQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.class(request);
        }, options);
    };
    const useClasses = ({ request, options }) => {
        return useQuery(["classesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.classes(request);
        }, options);
    };
    return {
        /** Balance queries the number of NFTs of a given class owned by the owner, same as balanceOf in ERC721 */ useBalance,
        /** Owner queries the owner of the NFT based on its class and id, same as ownerOf in ERC721 */ useOwner,
        /** Supply queries the number of NFTs from the given class, same as totalSupply of ERC721. */ useSupply,
        /**
         * NFTs queries all NFTs of a given class or owner,choose at least one of the two, similar to tokenByIndex in
         * ERC721Enumerable
         */
        useNFTs,
        /** NFT queries an NFT based on its class and id. */ useNFT,
        /** Class queries an NFT class based on its id */ useClass,
        /** Classes queries all NFT classes */ useClasses
    };
};
