import { PageRequest } from "../../base/query/v1beta1/pagination";
import { BinaryReader } from "../../../binary";
import { useQuery } from "@tanstack/react-query";
import { QueryAccountsRequest, QueryAccountsResponse, QueryAccountRequest, QueryAccountResponse, QueryParamsRequest, QueryParamsResponse, QueryModuleAccountsRequest, QueryModuleAccountsResponse, Bech32PrefixRequest, Bech32PrefixResponse, AddressBytesToStringRequest, AddressBytesToStringResponse, AddressStringToBytesRequest, AddressStringToBytesResponse } from "./query";
export class QueryClientImpl {
    rpc;
    constructor(rpc) {
        this.rpc = rpc;
    }
    /* Accounts returns all the existing accounts
    
     Since: cosmos-sdk 0.43 */
    accounts = async (request = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const data = QueryAccountsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "Accounts", data);
        return promise.then(data => QueryAccountsResponse.decode(new BinaryReader(data)));
    };
    /* Account returns account details based on address. */
    account = async (request) => {
        const data = QueryAccountRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "Account", data);
        return promise.then(data => QueryAccountResponse.decode(new BinaryReader(data)));
    };
    /* Params queries all parameters. */
    params = async (request = {}) => {
        const data = QueryParamsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "Params", data);
        return promise.then(data => QueryParamsResponse.decode(new BinaryReader(data)));
    };
    /* ModuleAccounts returns all the existing module accounts. */
    moduleAccounts = async (request = {}) => {
        const data = QueryModuleAccountsRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "ModuleAccounts", data);
        return promise.then(data => QueryModuleAccountsResponse.decode(new BinaryReader(data)));
    };
    /* Bech32 queries bech32Prefix */
    bech32Prefix = async (request = {}) => {
        const data = Bech32PrefixRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "Bech32Prefix", data);
        return promise.then(data => Bech32PrefixResponse.decode(new BinaryReader(data)));
    };
    /* AddressBytesToString converts Account Address bytes to string */
    addressBytesToString = async (request) => {
        const data = AddressBytesToStringRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "AddressBytesToString", data);
        return promise.then(data => AddressBytesToStringResponse.decode(new BinaryReader(data)));
    };
    /* AddressStringToBytes converts Address string to bytes */
    addressStringToBytes = async (request) => {
        const data = AddressStringToBytesRequest.encode(request).finish();
        const promise = this.rpc.request("cosmos.auth.v1beta1.Query", "AddressStringToBytes", data);
        return promise.then(data => AddressStringToBytesResponse.decode(new BinaryReader(data)));
    };
}
export const createClientImpl = (rpc) => {
    return new QueryClientImpl(rpc);
};
const _queryClients = new WeakMap();
const getQueryService = (rpc) => {
    if (!rpc)
        return;
    if (_queryClients.has(rpc)) {
        return _queryClients.get(rpc);
    }
    const queryService = new QueryClientImpl(rpc);
    _queryClients.set(rpc, queryService);
    return queryService;
};
export const createRpcQueryHooks = (rpc) => {
    const queryService = getQueryService(rpc);
    const useAccounts = ({ request, options }) => {
        return useQuery(["accountsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.accounts(request);
        }, options);
    };
    const useAccount = ({ request, options }) => {
        return useQuery(["accountQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.account(request);
        }, options);
    };
    const useParams = ({ request, options }) => {
        return useQuery(["paramsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.params(request);
        }, options);
    };
    const useModuleAccounts = ({ request, options }) => {
        return useQuery(["moduleAccountsQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.moduleAccounts(request);
        }, options);
    };
    const useBech32Prefix = ({ request, options }) => {
        return useQuery(["bech32PrefixQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.bech32Prefix(request);
        }, options);
    };
    const useAddressBytesToString = ({ request, options }) => {
        return useQuery(["addressBytesToStringQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.addressBytesToString(request);
        }, options);
    };
    const useAddressStringToBytes = ({ request, options }) => {
        return useQuery(["addressStringToBytesQuery", request], () => {
            if (!queryService)
                throw new Error("Query Service not initialized");
            return queryService.addressStringToBytes(request);
        }, options);
    };
    return {
        /**
         * Accounts returns all the existing accounts
         *
         * Since: cosmos-sdk 0.43
         */
        useAccounts,
        /** Account returns account details based on address. */ useAccount,
        /** Params queries all parameters. */ useParams,
        /** ModuleAccounts returns all the existing module accounts. */ useModuleAccounts,
        /** Bech32 queries bech32Prefix */ useBech32Prefix,
        /** AddressBytesToString converts Account Address bytes to string */ useAddressBytesToString,
        /** AddressStringToBytes converts Address string to bytes */ useAddressStringToBytes
    };
};
