import { PageRequest } from "../../cosmos/base/query/v1beta1/pagination";
import { setPaginationParams } from "../../helpers";
import { QueryParamsResponse, AssetTypeResponse, AllAssetsResponse, AssetMultiplierResponse, AllIntermediaryAccountsResponse, ConnectedIntermediaryAccountResponse, TotalSuperfluidDelegationsResponse, SuperfluidDelegationAmountResponse, SuperfluidDelegationsByDelegatorResponse, SuperfluidUndelegationsByDelegatorResponse, SuperfluidDelegationsByValidatorDenomResponse, EstimateSuperfluidDelegatedAmountByValidatorDenomResponse, QueryTotalDelegationByDelegatorResponse, QueryUnpoolWhitelistResponse } from "./query";
export class LCDQueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Params returns the total set of superfluid parameters. */
    params = async (_params = {}) => {
        const endpoint = `osmosis/superfluid/v1beta1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns superfluid asset type, whether if it's a native asset or an lp
     share. */
    assetType = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/superfluid/v1beta1/asset_type`;
        return AssetTypeResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns all registered superfluid assets. */
    allAssets = async (_params = {}) => {
        const endpoint = `osmosis/superfluid/v1beta1/all_assets`;
        return AllAssetsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns the osmo equivalent multiplier used in the most recent epoch. */
    assetMultiplier = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/superfluid/v1beta1/asset_multiplier`;
        return AssetMultiplierResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns all superfluid intermediary accounts. */
    allIntermediaryAccounts = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/superfluid/v1beta1/all_intermediary_accounts`;
        return AllIntermediaryAccountsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns intermediary account connected to a superfluid staked lock by id */
    connectedIntermediaryAccount = async (params) => {
        const endpoint = `osmosis/superfluid/v1beta1/connected_intermediary_account/${params.lockId}`;
        return ConnectedIntermediaryAccountResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns the total amount of osmo superfluidly staked.
     Response is denominated in uosmo. */
    totalSuperfluidDelegations = async (_params = {}) => {
        const endpoint = `osmosis/superfluid/v1beta1/all_superfluid_delegations`;
        return TotalSuperfluidDelegationsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns the coins superfluid delegated for the delegator, validator, denom
     triplet */
    superfluidDelegationAmount = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.delegatorAddress !== "undefined") {
            options.params.delegator_address = params.delegatorAddress;
        }
        if (typeof params?.validatorAddress !== "undefined") {
            options.params.validator_address = params.validatorAddress;
        }
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/superfluid/v1beta1/superfluid_delegation_amount`;
        return SuperfluidDelegationAmountResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns all the delegated superfluid poistions for a specific delegator. */
    superfluidDelegationsByDelegator = async (params) => {
        const endpoint = `osmosis/superfluid/v1beta1/superfluid_delegations/${params.delegatorAddress}`;
        return SuperfluidDelegationsByDelegatorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns all the undelegating superfluid poistions for a specific delegator. */
    superfluidUndelegationsByDelegator = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/superfluid/v1beta1/superfluid_undelegations_by_delegator/${params.delegatorAddress}`;
        return SuperfluidUndelegationsByDelegatorResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns all the superfluid positions of a specific denom delegated to one
     validator */
    superfluidDelegationsByValidatorDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.validatorAddress !== "undefined") {
            options.params.validator_address = params.validatorAddress;
        }
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/superfluid/v1beta1/superfluid_delegations_by_validator_denom`;
        return SuperfluidDelegationsByValidatorDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns the amount of a specific denom delegated to a specific validator
     This is labeled an estimate, because the way it calculates the amount can
     lead rounding errors from the true delegated amount */
    estimateSuperfluidDelegatedAmountByValidatorDenom = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.validatorAddress !== "undefined") {
            options.params.validator_address = params.validatorAddress;
        }
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `osmosis/superfluid/v1beta1/estimate_superfluid_delegation_amount_by_validator_denom`;
        return EstimateSuperfluidDelegatedAmountByValidatorDenomResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Returns the specified delegations for a specific delegator */
    totalDelegationByDelegator = async (params) => {
        const endpoint = `osmosis/superfluid/v1beta1/total_delegation_by_delegator/${params.delegatorAddress}`;
        return QueryTotalDelegationByDelegatorResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* Returns a list of whitelisted pool ids to unpool. */
    unpoolWhitelist = async (_params = {}) => {
        const endpoint = `osmosis/superfluid/v1beta1/unpool_whitelist`;
        return QueryUnpoolWhitelistResponse.fromSDKJSON(await this.req.get(endpoint));
    };
}
