import { DeepPartial } from "../../helpers";
import { BinaryReader, BinaryWriter } from "../../binary";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.api";
/**
 * Classifies set of possible modifications to an object in the service
 * configuration.
 */
export declare enum ChangeType {
    /** CHANGE_TYPE_UNSPECIFIED - No value was provided. */
    CHANGE_TYPE_UNSPECIFIED = 0,
    /**
     * ADDED - The changed object exists in the 'new' service configuration, but not
     * in the 'old' service configuration.
     */
    ADDED = 1,
    /**
     * REMOVED - The changed object exists in the 'old' service configuration, but not
     * in the 'new' service configuration.
     */
    REMOVED = 2,
    /**
     * MODIFIED - The changed object exists in both service configurations, but its value
     * is different.
     */
    MODIFIED = 3,
    UNRECOGNIZED = -1
}
export declare const ChangeTypeSDKType: typeof ChangeType;
export declare const ChangeTypeAmino: typeof ChangeType;
export declare function changeTypeFromJSON(object: any): ChangeType;
export declare function changeTypeToJSON(object: ChangeType): string;
/**
 * Output generated from semantically comparing two versions of a service
 * configuration.
 *
 * Includes detailed information about a field that have changed with
 * applicable advice about potential consequences for the change, such as
 * backwards-incompatibility.
 */
export interface ConfigChange {
    /**
     * Object hierarchy path to the change, with levels separated by a '.'
     * character. For repeated fields, an applicable unique identifier field is
     * used for the index (usually selector, name, or id). For maps, the term
     * 'key' is used. If the field has no unique identifier, the numeric index
     * is used.
     * Examples:
     * - visibility.rules[selector=="google.LibraryService.ListBooks"].restriction
     * - quota.metric_rules[selector=="google"].metric_costs[key=="reads"].value
     * - logging.producer_destinations[0]
     */
    element: string;
    /**
     * Value of the changed object in the old Service configuration,
     * in JSON format. This field will not be populated if ChangeType == ADDED.
     */
    oldValue: string;
    /**
     * Value of the changed object in the new Service configuration,
     * in JSON format. This field will not be populated if ChangeType == REMOVED.
     */
    newValue: string;
    /** The type for this change, either ADDED, REMOVED, or MODIFIED. */
    changeType: ChangeType;
    /**
     * Collection of advice provided for this change, useful for determining the
     * possible impact of this change.
     */
    advices: Advice[];
}
export interface ConfigChangeProtoMsg {
    typeUrl: "/google.api.ConfigChange";
    value: Uint8Array;
}
/**
 * Output generated from semantically comparing two versions of a service
 * configuration.
 *
 * Includes detailed information about a field that have changed with
 * applicable advice about potential consequences for the change, such as
 * backwards-incompatibility.
 */
export interface ConfigChangeAmino {
    /**
     * Object hierarchy path to the change, with levels separated by a '.'
     * character. For repeated fields, an applicable unique identifier field is
     * used for the index (usually selector, name, or id). For maps, the term
     * 'key' is used. If the field has no unique identifier, the numeric index
     * is used.
     * Examples:
     * - visibility.rules[selector=="google.LibraryService.ListBooks"].restriction
     * - quota.metric_rules[selector=="google"].metric_costs[key=="reads"].value
     * - logging.producer_destinations[0]
     */
    element?: string;
    /**
     * Value of the changed object in the old Service configuration,
     * in JSON format. This field will not be populated if ChangeType == ADDED.
     */
    old_value?: string;
    /**
     * Value of the changed object in the new Service configuration,
     * in JSON format. This field will not be populated if ChangeType == REMOVED.
     */
    new_value?: string;
    /** The type for this change, either ADDED, REMOVED, or MODIFIED. */
    change_type?: ChangeType;
    /**
     * Collection of advice provided for this change, useful for determining the
     * possible impact of this change.
     */
    advices?: AdviceAmino[];
}
export interface ConfigChangeAminoMsg {
    type: "/google.api.ConfigChange";
    value: ConfigChangeAmino;
}
/**
 * Output generated from semantically comparing two versions of a service
 * configuration.
 *
 * Includes detailed information about a field that have changed with
 * applicable advice about potential consequences for the change, such as
 * backwards-incompatibility.
 */
export interface ConfigChangeSDKType {
    element: string;
    old_value: string;
    new_value: string;
    change_type: ChangeType;
    advices: AdviceSDKType[];
}
/**
 * Generated advice about this change, used for providing more
 * information about how a change will affect the existing service.
 */
export interface Advice {
    /**
     * Useful description for why this advice was applied and what actions should
     * be taken to mitigate any implied risks.
     */
    description: string;
}
export interface AdviceProtoMsg {
    typeUrl: "/google.api.Advice";
    value: Uint8Array;
}
/**
 * Generated advice about this change, used for providing more
 * information about how a change will affect the existing service.
 */
export interface AdviceAmino {
    /**
     * Useful description for why this advice was applied and what actions should
     * be taken to mitigate any implied risks.
     */
    description?: string;
}
export interface AdviceAminoMsg {
    type: "/google.api.Advice";
    value: AdviceAmino;
}
/**
 * Generated advice about this change, used for providing more
 * information about how a change will affect the existing service.
 */
export interface AdviceSDKType {
    description: string;
}
export declare const ConfigChange: {
    typeUrl: string;
    is(o: any): o is ConfigChange;
    isSDK(o: any): o is ConfigChangeSDKType;
    isAmino(o: any): o is ConfigChangeAmino;
    encode(message: ConfigChange, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): ConfigChange;
    fromJSON(object: any): ConfigChange;
    toJSON(message: ConfigChange): JsonSafe<ConfigChange>;
    fromPartial(object: DeepPartial<ConfigChange>): ConfigChange;
    fromSDK(object: ConfigChangeSDKType): ConfigChange;
    fromSDKJSON(object: any): ConfigChangeSDKType;
    toSDK(message: ConfigChange): ConfigChangeSDKType;
    fromAmino(object: ConfigChangeAmino): ConfigChange;
    toAmino(message: ConfigChange): ConfigChangeAmino;
    fromAminoMsg(object: ConfigChangeAminoMsg): ConfigChange;
    fromProtoMsg(message: ConfigChangeProtoMsg): ConfigChange;
    toProto(message: ConfigChange): Uint8Array;
    toProtoMsg(message: ConfigChange): ConfigChangeProtoMsg;
    registerTypeUrl(): void;
};
export declare const Advice: {
    typeUrl: string;
    is(o: any): o is Advice;
    isSDK(o: any): o is AdviceSDKType;
    isAmino(o: any): o is AdviceAmino;
    encode(message: Advice, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Advice;
    fromJSON(object: any): Advice;
    toJSON(message: Advice): JsonSafe<Advice>;
    fromPartial(object: DeepPartial<Advice>): Advice;
    fromSDK(object: AdviceSDKType): Advice;
    fromSDKJSON(object: any): AdviceSDKType;
    toSDK(message: Advice): AdviceSDKType;
    fromAmino(object: AdviceAmino): Advice;
    toAmino(message: Advice): AdviceAmino;
    fromAminoMsg(object: AdviceAminoMsg): Advice;
    fromProtoMsg(message: AdviceProtoMsg): Advice;
    toProto(message: Advice): Uint8Array;
    toProtoMsg(message: Advice): AdviceProtoMsg;
    registerTypeUrl(): void;
};
