import { Any, AnyAmino, AnySDKType } from "../protobuf/any";
import { BinaryReader, BinaryWriter } from "../../binary";
import { DeepPartial } from "../../helpers";
import { JsonSafe } from "../../json-safe";
export declare const protobufPackage = "google.api";
/**
 * `Distribution` contains summary statistics for a population of values. It
 * optionally contains a histogram representing the distribution of those values
 * across a set of buckets.
 *
 * The summary statistics are the count, mean, sum of the squared deviation from
 * the mean, the minimum, and the maximum of the set of population of values.
 * The histogram is based on a sequence of buckets and gives a count of values
 * that fall into each bucket. The boundaries of the buckets are given either
 * explicitly or by formulas for buckets of fixed or exponentially increasing
 * widths.
 *
 * Although it is not forbidden, it is generally a bad idea to include
 * non-finite values (infinities or NaNs) in the population of values, as this
 * will render the `mean` and `sum_of_squared_deviation` fields meaningless.
 */
export interface Distribution {
    /**
     * The number of values in the population. Must be non-negative. This value
     * must equal the sum of the values in `bucket_counts` if a histogram is
     * provided.
     */
    count: bigint;
    /**
     * The arithmetic mean of the values in the population. If `count` is zero
     * then this field must be zero.
     */
    mean: number;
    /**
     * The sum of squared deviations from the mean of the values in the
     * population. For values x_i this is:
     *
     *     Sum[i=1..n]((x_i - mean)^2)
     *
     * Knuth, "The Art of Computer Programming", Vol. 2, page 232, 3rd edition
     * describes Welford's method for accumulating this sum in one pass.
     *
     * If `count` is zero then this field must be zero.
     */
    sumOfSquaredDeviation: number;
    /**
     * If specified, contains the range of the population values. The field
     * must not be present if the `count` is zero.
     */
    range?: Distribution_Range;
    /**
     * Defines the histogram bucket boundaries. If the distribution does not
     * contain a histogram, then omit this field.
     */
    bucketOptions?: Distribution_BucketOptions;
    /**
     * The number of values in each bucket of the histogram, as described in
     * `bucket_options`. If the distribution does not have a histogram, then omit
     * this field. If there is a histogram, then the sum of the values in
     * `bucket_counts` must equal the value in the `count` field of the
     * distribution.
     *
     * If present, `bucket_counts` should contain N values, where N is the number
     * of buckets specified in `bucket_options`. If you supply fewer than N
     * values, the remaining values are assumed to be 0.
     *
     * The order of the values in `bucket_counts` follows the bucket numbering
     * schemes described for the three bucket types. The first value must be the
     * count for the underflow bucket (number 0). The next N-2 values are the
     * counts for the finite buckets (number 1 through N-2). The N'th value in
     * `bucket_counts` is the count for the overflow bucket (number N-1).
     */
    bucketCounts: bigint[];
    /** Must be in increasing order of `value` field. */
    exemplars: Distribution_Exemplar[];
}
export interface DistributionProtoMsg {
    typeUrl: "/google.api.Distribution";
    value: Uint8Array;
}
/**
 * `Distribution` contains summary statistics for a population of values. It
 * optionally contains a histogram representing the distribution of those values
 * across a set of buckets.
 *
 * The summary statistics are the count, mean, sum of the squared deviation from
 * the mean, the minimum, and the maximum of the set of population of values.
 * The histogram is based on a sequence of buckets and gives a count of values
 * that fall into each bucket. The boundaries of the buckets are given either
 * explicitly or by formulas for buckets of fixed or exponentially increasing
 * widths.
 *
 * Although it is not forbidden, it is generally a bad idea to include
 * non-finite values (infinities or NaNs) in the population of values, as this
 * will render the `mean` and `sum_of_squared_deviation` fields meaningless.
 */
export interface DistributionAmino {
    /**
     * The number of values in the population. Must be non-negative. This value
     * must equal the sum of the values in `bucket_counts` if a histogram is
     * provided.
     */
    count?: string;
    /**
     * The arithmetic mean of the values in the population. If `count` is zero
     * then this field must be zero.
     */
    mean?: number;
    /**
     * The sum of squared deviations from the mean of the values in the
     * population. For values x_i this is:
     *
     *     Sum[i=1..n]((x_i - mean)^2)
     *
     * Knuth, "The Art of Computer Programming", Vol. 2, page 232, 3rd edition
     * describes Welford's method for accumulating this sum in one pass.
     *
     * If `count` is zero then this field must be zero.
     */
    sum_of_squared_deviation?: number;
    /**
     * If specified, contains the range of the population values. The field
     * must not be present if the `count` is zero.
     */
    range?: Distribution_RangeAmino;
    /**
     * Defines the histogram bucket boundaries. If the distribution does not
     * contain a histogram, then omit this field.
     */
    bucket_options?: Distribution_BucketOptionsAmino;
    /**
     * The number of values in each bucket of the histogram, as described in
     * `bucket_options`. If the distribution does not have a histogram, then omit
     * this field. If there is a histogram, then the sum of the values in
     * `bucket_counts` must equal the value in the `count` field of the
     * distribution.
     *
     * If present, `bucket_counts` should contain N values, where N is the number
     * of buckets specified in `bucket_options`. If you supply fewer than N
     * values, the remaining values are assumed to be 0.
     *
     * The order of the values in `bucket_counts` follows the bucket numbering
     * schemes described for the three bucket types. The first value must be the
     * count for the underflow bucket (number 0). The next N-2 values are the
     * counts for the finite buckets (number 1 through N-2). The N'th value in
     * `bucket_counts` is the count for the overflow bucket (number N-1).
     */
    bucket_counts?: string[];
    /** Must be in increasing order of `value` field. */
    exemplars?: Distribution_ExemplarAmino[];
}
export interface DistributionAminoMsg {
    type: "/google.api.Distribution";
    value: DistributionAmino;
}
/**
 * `Distribution` contains summary statistics for a population of values. It
 * optionally contains a histogram representing the distribution of those values
 * across a set of buckets.
 *
 * The summary statistics are the count, mean, sum of the squared deviation from
 * the mean, the minimum, and the maximum of the set of population of values.
 * The histogram is based on a sequence of buckets and gives a count of values
 * that fall into each bucket. The boundaries of the buckets are given either
 * explicitly or by formulas for buckets of fixed or exponentially increasing
 * widths.
 *
 * Although it is not forbidden, it is generally a bad idea to include
 * non-finite values (infinities or NaNs) in the population of values, as this
 * will render the `mean` and `sum_of_squared_deviation` fields meaningless.
 */
export interface DistributionSDKType {
    count: bigint;
    mean: number;
    sum_of_squared_deviation: number;
    range?: Distribution_RangeSDKType;
    bucket_options?: Distribution_BucketOptionsSDKType;
    bucket_counts: bigint[];
    exemplars: Distribution_ExemplarSDKType[];
}
/** The range of the population values. */
export interface Distribution_Range {
    /** The minimum of the population values. */
    min: number;
    /** The maximum of the population values. */
    max: number;
}
export interface Distribution_RangeProtoMsg {
    typeUrl: "/google.api.Range";
    value: Uint8Array;
}
/** The range of the population values. */
export interface Distribution_RangeAmino {
    /** The minimum of the population values. */
    min?: number;
    /** The maximum of the population values. */
    max?: number;
}
export interface Distribution_RangeAminoMsg {
    type: "/google.api.Range";
    value: Distribution_RangeAmino;
}
/** The range of the population values. */
export interface Distribution_RangeSDKType {
    min: number;
    max: number;
}
/**
 * `BucketOptions` describes the bucket boundaries used to create a histogram
 * for the distribution. The buckets can be in a linear sequence, an
 * exponential sequence, or each bucket can be specified explicitly.
 * `BucketOptions` does not include the number of values in each bucket.
 *
 * A bucket has an inclusive lower bound and exclusive upper bound for the
 * values that are counted for that bucket. The upper bound of a bucket must
 * be strictly greater than the lower bound. The sequence of N buckets for a
 * distribution consists of an underflow bucket (number 0), zero or more
 * finite buckets (number 1 through N - 2) and an overflow bucket (number N -
 * 1). The buckets are contiguous: the lower bound of bucket i (i > 0) is the
 * same as the upper bound of bucket i - 1. The buckets span the whole range
 * of finite values: lower bound of the underflow bucket is -infinity and the
 * upper bound of the overflow bucket is +infinity. The finite buckets are
 * so-called because both bounds are finite.
 */
export interface Distribution_BucketOptions {
    /** The linear bucket. */
    linearBuckets?: Distribution_BucketOptions_Linear;
    /** The exponential buckets. */
    exponentialBuckets?: Distribution_BucketOptions_Exponential;
    /** The explicit buckets. */
    explicitBuckets?: Distribution_BucketOptions_Explicit;
}
export interface Distribution_BucketOptionsProtoMsg {
    typeUrl: "/google.api.BucketOptions";
    value: Uint8Array;
}
/**
 * `BucketOptions` describes the bucket boundaries used to create a histogram
 * for the distribution. The buckets can be in a linear sequence, an
 * exponential sequence, or each bucket can be specified explicitly.
 * `BucketOptions` does not include the number of values in each bucket.
 *
 * A bucket has an inclusive lower bound and exclusive upper bound for the
 * values that are counted for that bucket. The upper bound of a bucket must
 * be strictly greater than the lower bound. The sequence of N buckets for a
 * distribution consists of an underflow bucket (number 0), zero or more
 * finite buckets (number 1 through N - 2) and an overflow bucket (number N -
 * 1). The buckets are contiguous: the lower bound of bucket i (i > 0) is the
 * same as the upper bound of bucket i - 1. The buckets span the whole range
 * of finite values: lower bound of the underflow bucket is -infinity and the
 * upper bound of the overflow bucket is +infinity. The finite buckets are
 * so-called because both bounds are finite.
 */
export interface Distribution_BucketOptionsAmino {
    /** The linear bucket. */
    linear_buckets?: Distribution_BucketOptions_LinearAmino;
    /** The exponential buckets. */
    exponential_buckets?: Distribution_BucketOptions_ExponentialAmino;
    /** The explicit buckets. */
    explicit_buckets?: Distribution_BucketOptions_ExplicitAmino;
}
export interface Distribution_BucketOptionsAminoMsg {
    type: "/google.api.BucketOptions";
    value: Distribution_BucketOptionsAmino;
}
/**
 * `BucketOptions` describes the bucket boundaries used to create a histogram
 * for the distribution. The buckets can be in a linear sequence, an
 * exponential sequence, or each bucket can be specified explicitly.
 * `BucketOptions` does not include the number of values in each bucket.
 *
 * A bucket has an inclusive lower bound and exclusive upper bound for the
 * values that are counted for that bucket. The upper bound of a bucket must
 * be strictly greater than the lower bound. The sequence of N buckets for a
 * distribution consists of an underflow bucket (number 0), zero or more
 * finite buckets (number 1 through N - 2) and an overflow bucket (number N -
 * 1). The buckets are contiguous: the lower bound of bucket i (i > 0) is the
 * same as the upper bound of bucket i - 1. The buckets span the whole range
 * of finite values: lower bound of the underflow bucket is -infinity and the
 * upper bound of the overflow bucket is +infinity. The finite buckets are
 * so-called because both bounds are finite.
 */
export interface Distribution_BucketOptionsSDKType {
    linear_buckets?: Distribution_BucketOptions_LinearSDKType;
    exponential_buckets?: Distribution_BucketOptions_ExponentialSDKType;
    explicit_buckets?: Distribution_BucketOptions_ExplicitSDKType;
}
/**
 * Specifies a linear sequence of buckets that all have the same width
 * (except overflow and underflow). Each bucket represents a constant
 * absolute uncertainty on the specific value in the bucket.
 *
 * There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the
 * following boundaries:
 *
 *    Upper bound (0 <= i < N-1):     offset + (width * i).
 *    Lower bound (1 <= i < N):       offset + (width * (i - 1)).
 */
export interface Distribution_BucketOptions_Linear {
    /** Must be greater than 0. */
    numFiniteBuckets: number;
    /** Must be greater than 0. */
    width: number;
    /** Lower bound of the first bucket. */
    offset: number;
}
export interface Distribution_BucketOptions_LinearProtoMsg {
    typeUrl: "/google.api.Linear";
    value: Uint8Array;
}
/**
 * Specifies a linear sequence of buckets that all have the same width
 * (except overflow and underflow). Each bucket represents a constant
 * absolute uncertainty on the specific value in the bucket.
 *
 * There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the
 * following boundaries:
 *
 *    Upper bound (0 <= i < N-1):     offset + (width * i).
 *    Lower bound (1 <= i < N):       offset + (width * (i - 1)).
 */
export interface Distribution_BucketOptions_LinearAmino {
    /** Must be greater than 0. */
    num_finite_buckets?: number;
    /** Must be greater than 0. */
    width?: number;
    /** Lower bound of the first bucket. */
    offset?: number;
}
export interface Distribution_BucketOptions_LinearAminoMsg {
    type: "/google.api.Linear";
    value: Distribution_BucketOptions_LinearAmino;
}
/**
 * Specifies a linear sequence of buckets that all have the same width
 * (except overflow and underflow). Each bucket represents a constant
 * absolute uncertainty on the specific value in the bucket.
 *
 * There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the
 * following boundaries:
 *
 *    Upper bound (0 <= i < N-1):     offset + (width * i).
 *    Lower bound (1 <= i < N):       offset + (width * (i - 1)).
 */
export interface Distribution_BucketOptions_LinearSDKType {
    num_finite_buckets: number;
    width: number;
    offset: number;
}
/**
 * Specifies an exponential sequence of buckets that have a width that is
 * proportional to the value of the lower bound. Each bucket represents a
 * constant relative uncertainty on a specific value in the bucket.
 *
 * There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the
 * following boundaries:
 *
 *    Upper bound (0 <= i < N-1):     scale * (growth_factor ^ i).
 *    Lower bound (1 <= i < N):       scale * (growth_factor ^ (i - 1)).
 */
export interface Distribution_BucketOptions_Exponential {
    /** Must be greater than 0. */
    numFiniteBuckets: number;
    /** Must be greater than 1. */
    growthFactor: number;
    /** Must be greater than 0. */
    scale: number;
}
export interface Distribution_BucketOptions_ExponentialProtoMsg {
    typeUrl: "/google.api.Exponential";
    value: Uint8Array;
}
/**
 * Specifies an exponential sequence of buckets that have a width that is
 * proportional to the value of the lower bound. Each bucket represents a
 * constant relative uncertainty on a specific value in the bucket.
 *
 * There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the
 * following boundaries:
 *
 *    Upper bound (0 <= i < N-1):     scale * (growth_factor ^ i).
 *    Lower bound (1 <= i < N):       scale * (growth_factor ^ (i - 1)).
 */
export interface Distribution_BucketOptions_ExponentialAmino {
    /** Must be greater than 0. */
    num_finite_buckets?: number;
    /** Must be greater than 1. */
    growth_factor?: number;
    /** Must be greater than 0. */
    scale?: number;
}
export interface Distribution_BucketOptions_ExponentialAminoMsg {
    type: "/google.api.Exponential";
    value: Distribution_BucketOptions_ExponentialAmino;
}
/**
 * Specifies an exponential sequence of buckets that have a width that is
 * proportional to the value of the lower bound. Each bucket represents a
 * constant relative uncertainty on a specific value in the bucket.
 *
 * There are `num_finite_buckets + 2` (= N) buckets. Bucket `i` has the
 * following boundaries:
 *
 *    Upper bound (0 <= i < N-1):     scale * (growth_factor ^ i).
 *    Lower bound (1 <= i < N):       scale * (growth_factor ^ (i - 1)).
 */
export interface Distribution_BucketOptions_ExponentialSDKType {
    num_finite_buckets: number;
    growth_factor: number;
    scale: number;
}
/**
 * Specifies a set of buckets with arbitrary widths.
 *
 * There are `size(bounds) + 1` (= N) buckets. Bucket `i` has the following
 * boundaries:
 *
 *    Upper bound (0 <= i < N-1):     bounds[i]
 *    Lower bound (1 <= i < N);       bounds[i - 1]
 *
 * The `bounds` field must contain at least one element. If `bounds` has
 * only one element, then there are no finite buckets, and that single
 * element is the common boundary of the overflow and underflow buckets.
 */
export interface Distribution_BucketOptions_Explicit {
    /** The values must be monotonically increasing. */
    bounds: number[];
}
export interface Distribution_BucketOptions_ExplicitProtoMsg {
    typeUrl: "/google.api.Explicit";
    value: Uint8Array;
}
/**
 * Specifies a set of buckets with arbitrary widths.
 *
 * There are `size(bounds) + 1` (= N) buckets. Bucket `i` has the following
 * boundaries:
 *
 *    Upper bound (0 <= i < N-1):     bounds[i]
 *    Lower bound (1 <= i < N);       bounds[i - 1]
 *
 * The `bounds` field must contain at least one element. If `bounds` has
 * only one element, then there are no finite buckets, and that single
 * element is the common boundary of the overflow and underflow buckets.
 */
export interface Distribution_BucketOptions_ExplicitAmino {
    /** The values must be monotonically increasing. */
    bounds?: number[];
}
export interface Distribution_BucketOptions_ExplicitAminoMsg {
    type: "/google.api.Explicit";
    value: Distribution_BucketOptions_ExplicitAmino;
}
/**
 * Specifies a set of buckets with arbitrary widths.
 *
 * There are `size(bounds) + 1` (= N) buckets. Bucket `i` has the following
 * boundaries:
 *
 *    Upper bound (0 <= i < N-1):     bounds[i]
 *    Lower bound (1 <= i < N);       bounds[i - 1]
 *
 * The `bounds` field must contain at least one element. If `bounds` has
 * only one element, then there are no finite buckets, and that single
 * element is the common boundary of the overflow and underflow buckets.
 */
export interface Distribution_BucketOptions_ExplicitSDKType {
    bounds: number[];
}
/**
 * Exemplars are example points that may be used to annotate aggregated
 * distribution values. They are metadata that gives information about a
 * particular value added to a Distribution bucket, such as a trace ID that
 * was active when a value was added. They may contain further information,
 * such as a example values and timestamps, origin, etc.
 */
export interface Distribution_Exemplar {
    /**
     * Value of the exemplar point. This value determines to which bucket the
     * exemplar belongs.
     */
    value: number;
    /** The observation (sampling) time of the above value. */
    timestamp?: Date;
    /**
     * Contextual information about the example value. Examples are:
     *
     *   Trace: type.googleapis.com/google.monitoring.v3.SpanContext
     *
     *   Literal string: type.googleapis.com/google.protobuf.StringValue
     *
     *   Labels dropped during aggregation:
     *     type.googleapis.com/google.monitoring.v3.DroppedLabels
     *
     * There may be only a single attachment of any given message type in a
     * single exemplar, and this is enforced by the system.
     */
    attachments: Any[];
}
export interface Distribution_ExemplarProtoMsg {
    typeUrl: "/google.api.Exemplar";
    value: Uint8Array;
}
/**
 * Exemplars are example points that may be used to annotate aggregated
 * distribution values. They are metadata that gives information about a
 * particular value added to a Distribution bucket, such as a trace ID that
 * was active when a value was added. They may contain further information,
 * such as a example values and timestamps, origin, etc.
 */
export interface Distribution_ExemplarAmino {
    /**
     * Value of the exemplar point. This value determines to which bucket the
     * exemplar belongs.
     */
    value?: number;
    /** The observation (sampling) time of the above value. */
    timestamp?: string;
    /**
     * Contextual information about the example value. Examples are:
     *
     *   Trace: type.googleapis.com/google.monitoring.v3.SpanContext
     *
     *   Literal string: type.googleapis.com/google.protobuf.StringValue
     *
     *   Labels dropped during aggregation:
     *     type.googleapis.com/google.monitoring.v3.DroppedLabels
     *
     * There may be only a single attachment of any given message type in a
     * single exemplar, and this is enforced by the system.
     */
    attachments?: AnyAmino[];
}
export interface Distribution_ExemplarAminoMsg {
    type: "/google.api.Exemplar";
    value: Distribution_ExemplarAmino;
}
/**
 * Exemplars are example points that may be used to annotate aggregated
 * distribution values. They are metadata that gives information about a
 * particular value added to a Distribution bucket, such as a trace ID that
 * was active when a value was added. They may contain further information,
 * such as a example values and timestamps, origin, etc.
 */
export interface Distribution_ExemplarSDKType {
    value: number;
    timestamp?: Date;
    attachments: AnySDKType[];
}
export declare const Distribution: {
    typeUrl: string;
    is(o: any): o is Distribution;
    isSDK(o: any): o is DistributionSDKType;
    isAmino(o: any): o is DistributionAmino;
    encode(message: Distribution, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution;
    fromJSON(object: any): Distribution;
    toJSON(message: Distribution): JsonSafe<Distribution>;
    fromPartial(object: DeepPartial<Distribution>): Distribution;
    fromSDK(object: DistributionSDKType): Distribution;
    fromSDKJSON(object: any): DistributionSDKType;
    toSDK(message: Distribution): DistributionSDKType;
    fromAmino(object: DistributionAmino): Distribution;
    toAmino(message: Distribution): DistributionAmino;
    fromAminoMsg(object: DistributionAminoMsg): Distribution;
    fromProtoMsg(message: DistributionProtoMsg): Distribution;
    toProto(message: Distribution): Uint8Array;
    toProtoMsg(message: Distribution): DistributionProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_Range: {
    typeUrl: string;
    is(o: any): o is Distribution_Range;
    isSDK(o: any): o is Distribution_RangeSDKType;
    isAmino(o: any): o is Distribution_RangeAmino;
    encode(message: Distribution_Range, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_Range;
    fromJSON(object: any): Distribution_Range;
    toJSON(message: Distribution_Range): JsonSafe<Distribution_Range>;
    fromPartial(object: DeepPartial<Distribution_Range>): Distribution_Range;
    fromSDK(object: Distribution_RangeSDKType): Distribution_Range;
    fromSDKJSON(object: any): Distribution_RangeSDKType;
    toSDK(message: Distribution_Range): Distribution_RangeSDKType;
    fromAmino(object: Distribution_RangeAmino): Distribution_Range;
    toAmino(message: Distribution_Range): Distribution_RangeAmino;
    fromAminoMsg(object: Distribution_RangeAminoMsg): Distribution_Range;
    fromProtoMsg(message: Distribution_RangeProtoMsg): Distribution_Range;
    toProto(message: Distribution_Range): Uint8Array;
    toProtoMsg(message: Distribution_Range): Distribution_RangeProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_BucketOptions: {
    typeUrl: string;
    is(o: any): o is Distribution_BucketOptions;
    isSDK(o: any): o is Distribution_BucketOptionsSDKType;
    isAmino(o: any): o is Distribution_BucketOptionsAmino;
    encode(message: Distribution_BucketOptions, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_BucketOptions;
    fromJSON(object: any): Distribution_BucketOptions;
    toJSON(message: Distribution_BucketOptions): JsonSafe<Distribution_BucketOptions>;
    fromPartial(object: DeepPartial<Distribution_BucketOptions>): Distribution_BucketOptions;
    fromSDK(object: Distribution_BucketOptionsSDKType): Distribution_BucketOptions;
    fromSDKJSON(object: any): Distribution_BucketOptionsSDKType;
    toSDK(message: Distribution_BucketOptions): Distribution_BucketOptionsSDKType;
    fromAmino(object: Distribution_BucketOptionsAmino): Distribution_BucketOptions;
    toAmino(message: Distribution_BucketOptions): Distribution_BucketOptionsAmino;
    fromAminoMsg(object: Distribution_BucketOptionsAminoMsg): Distribution_BucketOptions;
    fromProtoMsg(message: Distribution_BucketOptionsProtoMsg): Distribution_BucketOptions;
    toProto(message: Distribution_BucketOptions): Uint8Array;
    toProtoMsg(message: Distribution_BucketOptions): Distribution_BucketOptionsProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_BucketOptions_Linear: {
    typeUrl: string;
    is(o: any): o is Distribution_BucketOptions_Linear;
    isSDK(o: any): o is Distribution_BucketOptions_LinearSDKType;
    isAmino(o: any): o is Distribution_BucketOptions_LinearAmino;
    encode(message: Distribution_BucketOptions_Linear, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_BucketOptions_Linear;
    fromJSON(object: any): Distribution_BucketOptions_Linear;
    toJSON(message: Distribution_BucketOptions_Linear): JsonSafe<Distribution_BucketOptions_Linear>;
    fromPartial(object: DeepPartial<Distribution_BucketOptions_Linear>): Distribution_BucketOptions_Linear;
    fromSDK(object: Distribution_BucketOptions_LinearSDKType): Distribution_BucketOptions_Linear;
    fromSDKJSON(object: any): Distribution_BucketOptions_LinearSDKType;
    toSDK(message: Distribution_BucketOptions_Linear): Distribution_BucketOptions_LinearSDKType;
    fromAmino(object: Distribution_BucketOptions_LinearAmino): Distribution_BucketOptions_Linear;
    toAmino(message: Distribution_BucketOptions_Linear): Distribution_BucketOptions_LinearAmino;
    fromAminoMsg(object: Distribution_BucketOptions_LinearAminoMsg): Distribution_BucketOptions_Linear;
    fromProtoMsg(message: Distribution_BucketOptions_LinearProtoMsg): Distribution_BucketOptions_Linear;
    toProto(message: Distribution_BucketOptions_Linear): Uint8Array;
    toProtoMsg(message: Distribution_BucketOptions_Linear): Distribution_BucketOptions_LinearProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_BucketOptions_Exponential: {
    typeUrl: string;
    is(o: any): o is Distribution_BucketOptions_Exponential;
    isSDK(o: any): o is Distribution_BucketOptions_ExponentialSDKType;
    isAmino(o: any): o is Distribution_BucketOptions_ExponentialAmino;
    encode(message: Distribution_BucketOptions_Exponential, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_BucketOptions_Exponential;
    fromJSON(object: any): Distribution_BucketOptions_Exponential;
    toJSON(message: Distribution_BucketOptions_Exponential): JsonSafe<Distribution_BucketOptions_Exponential>;
    fromPartial(object: DeepPartial<Distribution_BucketOptions_Exponential>): Distribution_BucketOptions_Exponential;
    fromSDK(object: Distribution_BucketOptions_ExponentialSDKType): Distribution_BucketOptions_Exponential;
    fromSDKJSON(object: any): Distribution_BucketOptions_ExponentialSDKType;
    toSDK(message: Distribution_BucketOptions_Exponential): Distribution_BucketOptions_ExponentialSDKType;
    fromAmino(object: Distribution_BucketOptions_ExponentialAmino): Distribution_BucketOptions_Exponential;
    toAmino(message: Distribution_BucketOptions_Exponential): Distribution_BucketOptions_ExponentialAmino;
    fromAminoMsg(object: Distribution_BucketOptions_ExponentialAminoMsg): Distribution_BucketOptions_Exponential;
    fromProtoMsg(message: Distribution_BucketOptions_ExponentialProtoMsg): Distribution_BucketOptions_Exponential;
    toProto(message: Distribution_BucketOptions_Exponential): Uint8Array;
    toProtoMsg(message: Distribution_BucketOptions_Exponential): Distribution_BucketOptions_ExponentialProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_BucketOptions_Explicit: {
    typeUrl: string;
    is(o: any): o is Distribution_BucketOptions_Explicit;
    isSDK(o: any): o is Distribution_BucketOptions_ExplicitSDKType;
    isAmino(o: any): o is Distribution_BucketOptions_ExplicitAmino;
    encode(message: Distribution_BucketOptions_Explicit, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_BucketOptions_Explicit;
    fromJSON(object: any): Distribution_BucketOptions_Explicit;
    toJSON(message: Distribution_BucketOptions_Explicit): JsonSafe<Distribution_BucketOptions_Explicit>;
    fromPartial(object: DeepPartial<Distribution_BucketOptions_Explicit>): Distribution_BucketOptions_Explicit;
    fromSDK(object: Distribution_BucketOptions_ExplicitSDKType): Distribution_BucketOptions_Explicit;
    fromSDKJSON(object: any): Distribution_BucketOptions_ExplicitSDKType;
    toSDK(message: Distribution_BucketOptions_Explicit): Distribution_BucketOptions_ExplicitSDKType;
    fromAmino(object: Distribution_BucketOptions_ExplicitAmino): Distribution_BucketOptions_Explicit;
    toAmino(message: Distribution_BucketOptions_Explicit): Distribution_BucketOptions_ExplicitAmino;
    fromAminoMsg(object: Distribution_BucketOptions_ExplicitAminoMsg): Distribution_BucketOptions_Explicit;
    fromProtoMsg(message: Distribution_BucketOptions_ExplicitProtoMsg): Distribution_BucketOptions_Explicit;
    toProto(message: Distribution_BucketOptions_Explicit): Uint8Array;
    toProtoMsg(message: Distribution_BucketOptions_Explicit): Distribution_BucketOptions_ExplicitProtoMsg;
    registerTypeUrl(): void;
};
export declare const Distribution_Exemplar: {
    typeUrl: string;
    is(o: any): o is Distribution_Exemplar;
    isSDK(o: any): o is Distribution_ExemplarSDKType;
    isAmino(o: any): o is Distribution_ExemplarAmino;
    encode(message: Distribution_Exemplar, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): Distribution_Exemplar;
    fromJSON(object: any): Distribution_Exemplar;
    toJSON(message: Distribution_Exemplar): JsonSafe<Distribution_Exemplar>;
    fromPartial(object: DeepPartial<Distribution_Exemplar>): Distribution_Exemplar;
    fromSDK(object: Distribution_ExemplarSDKType): Distribution_Exemplar;
    fromSDKJSON(object: any): Distribution_ExemplarSDKType;
    toSDK(message: Distribution_Exemplar): Distribution_ExemplarSDKType;
    fromAmino(object: Distribution_ExemplarAmino): Distribution_Exemplar;
    toAmino(message: Distribution_Exemplar): Distribution_ExemplarAmino;
    fromAminoMsg(object: Distribution_ExemplarAminoMsg): Distribution_Exemplar;
    fromProtoMsg(message: Distribution_ExemplarProtoMsg): Distribution_Exemplar;
    toProto(message: Distribution_Exemplar): Uint8Array;
    toProtoMsg(message: Distribution_Exemplar): Distribution_ExemplarProtoMsg;
    registerTypeUrl(): void;
};
