import { setPaginationParams } from "../helpers";
import { PageRequest } from "../cosmos/base/query/v1beta1/pagination";
import { QueryBalanceResponse, QueryAllBalancesResponse, QuerySpendableBalancesResponse, QueryTotalSupplyResponse, QuerySupplyOfResponse, QueryParamsResponse, QueryDenomMetadataResponse, QueryDenomsMetadataResponse, QueryDenomOwnersResponse } from "../cosmos/bank/v1beta1/query";
import { QueryPoolsResponse, QueryNumPoolsResponse, QueryTotalLiquidityResponse, QueryPoolsWithFilterResponse, QueryPoolResponse, QueryPoolTypeResponse, QueryCalcJoinPoolSharesResponse, QueryCalcExitPoolCoinsFromSharesResponse, QueryPoolParamsResponse, QueryTotalPoolLiquidityResponse, QueryTotalSharesResponse, QuerySpotPriceResponse, QuerySwapExactAmountInResponse, QuerySwapExactAmountOutResponse } from "./gamm/v1beta1/query";
export class QueryClient {
    req;
    constructor({ requestClient }) {
        this.req = requestClient;
    }
    /* Balance queries the balance of a single coin for a single account. */
    balance = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `cosmos/bank/v1beta1/balances/${params.address}/by_denom`;
        return QueryBalanceResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* AllBalances queries the balance of all coins for a single account. */
    allBalances = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/balances/${params.address}`;
        return QueryAllBalancesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* SpendableBalances queries the spenable balance of all coins for a single
     account. */
    spendableBalances = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/spendable_balances/${params.address}`;
        return QuerySpendableBalancesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* TotalSupply queries the total supply of all coins. */
    totalSupply = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/supply`;
        return QueryTotalSupplyResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* SupplyOf queries the supply of a single coin. */
    supplyOf = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.denom !== "undefined") {
            options.params.denom = params.denom;
        }
        const endpoint = `cosmos/bank/v1beta1/supply/by_denom`;
        return QuerySupplyOfResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Params queries the parameters of x/bank module. */
    params = async (_params = {}) => {
        const endpoint = `cosmos/bank/v1beta1/params`;
        return QueryParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DenomsMetadata queries the client metadata of a given coin denomination. */
    denomMetadata = async (params) => {
        const endpoint = `cosmos/bank/v1beta1/denoms_metadata/${params.denom}`;
        return QueryDenomMetadataResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* DenomsMetadata queries the client metadata for all registered coin
     denominations. */
    denomsMetadata = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/denoms_metadata`;
        return QueryDenomsMetadataResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* DenomOwners queries for all account addresses that own a particular token
     denomination. */
    denomOwners = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `cosmos/bank/v1beta1/denom_owners/${params.denom}`;
        return QueryDenomOwnersResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Pools */
    pools = async (params = {
        pagination: PageRequest.fromPartial({})
    }) => {
        const options = {
            params: {}
        };
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/gamm/v1beta1/pools`;
        return QueryPoolsResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* NumPools */
    numPools = async (_params = {}) => {
        const endpoint = `osmosis/gamm/v1beta1/num_pools`;
        return QueryNumPoolsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* TotalLiquidity */
    totalLiquidity = async (_params = {}) => {
        const endpoint = `osmosis/gamm/v1beta1/total_liquidity`;
        return QueryTotalLiquidityResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* PoolsWithFilter allows you to query specific pools with requested
     parameters */
    poolsWithFilter = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.minLiquidity !== "undefined") {
            options.params.min_liquidity = params.minLiquidity;
        }
        if (typeof params?.poolType !== "undefined") {
            options.params.pool_type = params.poolType;
        }
        if (typeof params?.pagination !== "undefined") {
            setPaginationParams(options, params.pagination);
        }
        const endpoint = `osmosis/gamm/v1beta1/filtered_pools`;
        return QueryPoolsWithFilterResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Per Pool gRPC Endpoints */
    pool = async (params) => {
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}`;
        return QueryPoolResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* PoolType returns the type of the pool.
     Returns "Balancer" as a string literal when the pool is a balancer pool.
     Errors if the pool is failed to be type caseted. */
    poolType = async (params) => {
        const endpoint = `osmosis/gamm/v1beta1/pool_type/${params.poolId}`;
        return QueryPoolTypeResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* CalcJoinPoolShares */
    calcJoinPoolShares = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.tokensIn !== "undefined") {
            options.params.tokens_in = params.tokensIn;
        }
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}/join_swap_exact_in`;
        return QueryCalcJoinPoolSharesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* CalcExitPoolCoinsFromShares */
    calcExitPoolCoinsFromShares = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.shareInAmount !== "undefined") {
            options.params.share_in_amount = params.shareInAmount;
        }
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}/exit_swap_share_amount_in`;
        return QueryCalcExitPoolCoinsFromSharesResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* PoolParams */
    poolParams = async (params) => {
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}/params`;
        return QueryPoolParamsResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* TotalPoolLiquidity */
    totalPoolLiquidity = async (params) => {
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}/total_pool_liquidity`;
        return QueryTotalPoolLiquidityResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* TotalShares */
    totalShares = async (params) => {
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}/total_shares`;
        return QueryTotalSharesResponse.fromSDKJSON(await this.req.get(endpoint));
    };
    /* SpotPrice defines a gRPC query handler that returns the spot price given
     a base denomination and a quote denomination. */
    spotPrice = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.baseAssetDenom !== "undefined") {
            options.params.base_asset_denom = params.baseAssetDenom;
        }
        if (typeof params?.quoteAssetDenom !== "undefined") {
            options.params.quote_asset_denom = params.quoteAssetDenom;
        }
        const endpoint = `osmosis/gamm/v1beta1/pools/${params.poolId}/prices`;
        return QuerySpotPriceResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* Estimate the swap. */
    estimateSwapExactAmountIn = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.sender !== "undefined") {
            options.params.sender = params.sender;
        }
        if (typeof params?.tokenIn !== "undefined") {
            options.params.token_in = params.tokenIn;
        }
        if (typeof params?.routes !== "undefined") {
            options.params.routes = params.routes;
        }
        const endpoint = `osmosis/gamm/v1beta1/${params.poolId}/estimate/swap_exact_amount_in`;
        return QuerySwapExactAmountInResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
    /* EstimateSwapExactAmountOut */
    estimateSwapExactAmountOut = async (params) => {
        const options = {
            params: {}
        };
        if (typeof params?.sender !== "undefined") {
            options.params.sender = params.sender;
        }
        if (typeof params?.routes !== "undefined") {
            options.params.routes = params.routes;
        }
        if (typeof params?.tokenOut !== "undefined") {
            options.params.token_out = params.tokenOut;
        }
        const endpoint = `osmosis/gamm/v1beta1/${params.poolId}/estimate/swap_exact_amount_out`;
        return QuerySwapExactAmountOutResponse.fromSDKJSON(await this.req.get(endpoint, options));
    };
}
